import os
import logging

from constants import CheckStatus
from constants import Feature
from constants import PrecheckPlugin
from constants import Url
from constants import CLUSTER_API_HOST
from precheck.plugin_base import PluginBase
from utils import requests_wrapper


class PluginLicense(PluginBase):
    id = PrecheckPlugin.LICENSE
    name = "feature.precheck.licenseName"
    desc = "feature.precheck.licenseDesc"
    feature = Feature.MALWAREPREVENTION

    def check(self):
        try:
            self.report_check_status(CheckStatus.INPROGRESS, "")
            # create request parameters
            cluster_api_port = os.environ["CLUSTER_API_SERVICE_PORT"]
            url = Url.InCluster.LIST_ALL_FEATURES.format(
                     service_host=CLUSTER_API_HOST,
                     service_port=cluster_api_port)
            logging.info("Calling GET API for listing all features")
            response = requests_wrapper.incluster_request('GET', url)
            json_response = response.json()
            valid_license_found = False
            for feature in json_response["result"]:
               name = feature["name"]
               if (name == Feature.MALWAREPREVENTION):
                    valid_license_found = feature["allowed"]
                    reason = feature["disallowReason"]
                    break

            if not valid_license_found:
                self.report_check_status(
                    CheckStatus.FAILED,
                    reason)
            else:
                self.report_check_status(CheckStatus.SUCCESS)
        except Exception as e:
            self.report_check_status(
                CheckStatus.FAILED,
                "API invocation failed: {msg}".format(msg=e))
            logging.exception(e)
            raise